'use client';

import { useAdmin } from '@/contexts/AdminContext';
import { adminSignOut } from '@/utils/admin_auth';
import { useRouter } from 'next/navigation';
import { motion } from 'framer-motion';
import { useEffect, useState } from 'react';
import { 
  FiUsers, 
  FiBook, 
  FiAward, 
  FiClock, 
  FiPlus, 
  FiBarChart2 
} from 'react-icons/fi';
import { getSubjects, getTopics, getContents } from '@/utils/firebase_utils';
import type { DashboardStats, Content, QuickAction } from '@/types/education';

function AdminSkeleton() {
  return (
    <div className="space-y-8 animate-pulse">
      {/* Header Skeleton */}
      <div className="bg-[#1a1a1a] rounded-2xl p-8">
        <div className="h-8 w-48 bg-[#2a2a2a] rounded mb-4"></div>
        <div className="flex items-center justify-between">
          <div>
            <div className="h-4 w-32 bg-[#2a2a2a] rounded mb-2"></div>
            <div className="h-6 w-48 bg-[#2a2a2a] rounded mb-2"></div>
            <div className="h-4 w-24 bg-[#2a2a2a] rounded"></div>
          </div>
          <div className="h-10 w-24 bg-[#2a2a2a] rounded"></div>
        </div>
      </div>

      {/* Stats Skeleton */}
      <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
        {[1, 2, 3].map((i) => (
          <div key={i} className="bg-[#1a1a1a] rounded-lg p-6">
            <div className="h-6 w-32 bg-[#2a2a2a] rounded mb-2"></div>
            <div className="h-8 w-24 bg-[#2a2a2a] rounded"></div>
          </div>
        ))}
      </div>
    </div>
  );
}

const quickActions: QuickAction[] = [
  { 
    title: 'Add Subject', 
    icon: <FiPlus />, 
    path: '/admin/content/subjects/new',
    permission: 'CONTENT'
  },
  { 
    title: 'Add Topic', 
    icon: <FiBook />, 
    path: '/admin/content/topics/new',
    permission: 'CONTENT'
  },
  { 
    title: 'Add Content', 
    icon: <FiAward />, 
    path: '/admin/content/new',
    permission: 'CONTENT'
  },
  { 
    title: 'View Analytics', 
    icon: <FiBarChart2 />, 
    path: '/admin/analytics',
    permission: 'ANALYTICS'
  }
];

export default function AdminDashboard() {
  const { adminData, loading } = useAdmin();
  const router = useRouter();
  const [isOffline, setIsOffline] = useState(false);
  const [isClient, setIsClient] = useState(false);
  const [stats, setStats] = useState<DashboardStats>({
    totalSubjects: 0,
    totalTopics: 0,
    totalContent: 0,
    recentActivities: []
  });

  useEffect(() => {
    setIsClient(true);
    setIsOffline(!navigator.onLine);
    const handleOnline = () => setIsOffline(false);
    const handleOffline = () => setIsOffline(true);

    window.addEventListener('online', handleOnline);
    window.addEventListener('offline', handleOffline);

    if (adminData?.permissions) {
      loadStats();
    }

    return () => {
      window.removeEventListener('online', handleOnline);
      window.removeEventListener('offline', handleOffline);
    };
  }, [adminData]);

  const loadStats = async () => {
    try {
      const [subjects, topics, contents] = await Promise.all([
        getSubjects({ isActive: true }),
        getTopics({ isActive: true }),
        getContents({ isActive: true })
      ]);

      setStats({
        totalSubjects: subjects.items.length,
        totalTopics: topics.items.length,
        totalContent: contents.items.length,
        recentActivities: contents.items
          .sort((a, b) => new Date(b.updatedAt).getTime() - new Date(a.updatedAt).getTime())
          .slice(0, 5)
      });
    } catch (error) {
      console.error('Error loading stats:', error);
    }
  };

  const handleSignOut = async () => {
    try {
      await adminSignOut();
      router.push('/login');
    } catch (error) {
      console.error('Error signing out:', error);
    }
  };

  const handleActionClick = (action: QuickAction) => {
    if (!adminData?.permissions.includes(action.permission || '')) {
      alert('You do not have permission to access this feature');
      return;
    }
    router.push(action.path);
  };

  // Show skeleton during SSR or loading
  if (!isClient || loading) {
    return <AdminSkeleton />;
  }

  if (!adminData) {
    return (
      <div className="text-center py-12">
        <h2 className="text-xl text-red-500">Access Denied. Please log in with admin credentials.</h2>
        <button 
          onClick={() => router.push('/login')}
          className="mt-4 px-4 py-2 bg-[#FF6B2B] text-white rounded-lg hover:bg-[#FF6B2B]/90"
        >
          Back to Login
        </button>
      </div>
    );
  }

  const statCards = [
    {
      title: 'Total Subjects',
      value: stats.totalSubjects,
      icon: <FiBook className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37]'
    },
    {
      title: 'Total Topics',
      value: stats.totalTopics,
      icon: <FiAward className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37] opacity-90'
    },
    {
      title: 'Total Content',
      value: stats.totalContent,
      icon: <FiClock className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37] opacity-80'
    }
  ];

  return (
    <div className="space-y-8">
      {isOffline && (
        <div className="bg-yellow-500/10 border border-yellow-500/20 rounded-lg p-4 mb-6">
          <p className="text-yellow-500 flex items-center">
            <svg className="w-5 h-5 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z" />
            </svg>
            You are currently offline. Some features may be limited.
          </p>
        </div>
      )}

      {/* Admin Header */}
      <div className="bg-[#1a1a1a] rounded-2xl p-8">
        <h1 className="text-3xl font-bold text-white mb-4">
          Welcome Back {isOffline && '(Offline Mode)'}
        </h1>
        <div className="flex items-center justify-between">
          <div>
            <p className="text-xl font-semibold text-[#ededed]">
              {adminData.email}
            </p>
            <p className="text-[#FF6B2B] font-medium mt-1">
              {adminData.role}
            </p>
          </div>
          <motion.button
            whileHover={{ scale: 1.02 }}
            whileTap={{ scale: 0.98 }}
            onClick={handleSignOut}
            className="px-4 py-2 rounded-lg bg-red-500/10 text-red-500 hover:bg-red-500/20 transition-colors"
          >
            Sign Out
          </motion.button>
        </div>
      </div>

      {/* Stats Grid */}
      <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
        {statCards.map((stat, index) => (
          <motion.div
            key={stat.title}
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: index * 0.1 }}
            className={`bg-gradient-to-br ${stat.color} p-6 rounded-lg shadow-lg`}
          >
            <div className="flex items-center justify-between">
              <div>
                <p className="text-white text-sm font-medium">{stat.title}</p>
                <p className="text-white text-2xl font-bold mt-2">{stat.value}</p>
              </div>
              <div className="bg-white/10 p-3 rounded-lg">
                {stat.icon}
              </div>
            </div>
          </motion.div>
        ))}
      </div>

      {/* Recent Activity */}
      <div className="bg-[#1a1a1a] rounded-lg shadow-lg p-6">
        <h2 className="text-xl font-semibold mb-4 text-white">Recent Activity</h2>
        <div className="space-y-4">
          {stats.recentActivities.map((activity: Content, index: number) => (
            <motion.div
              key={activity.id}
              initial={{ opacity: 0, x: -20 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ delay: index * 0.1 }}
              className="flex items-center justify-between p-4 bg-[#2a2a2a] rounded-lg cursor-pointer hover:bg-[#2a2a2a]/80"
              onClick={() => router.push(`/admin/content/${activity.id}`)}
            >
              <div className="flex items-center space-x-4">
                <div className="bg-[#FF6B2B]/10 p-2 rounded-lg">
                  <FiClock className="w-5 h-5 text-[#FF6B2B]" />
                </div>
                <div>
                  <h3 className="text-white font-medium">{activity.title}</h3>
                  <p className="text-gray-400 text-sm">
                    {new Date(activity.updatedAt).toLocaleDateString()}
                  </p>
                </div>
              </div>
              <span className={`px-3 py-1 rounded-full text-xs font-medium
                ${activity.reviewStatus === 'PUBLISHED' 
                  ? 'bg-green-500/10 text-green-500' 
                  : activity.reviewStatus === 'PENDING'
                  ? 'bg-yellow-500/10 text-yellow-500'
                  : 'bg-gray-500/10 text-gray-500'
                }`}>
                {activity.reviewStatus}
              </span>
            </motion.div>
          ))}
        </div>
      </div>

      {/* Quick Actions */}
      <div className="bg-[#1a1a1a] rounded-lg shadow-lg p-6">
        <h2 className="text-xl font-semibold mb-4 text-white">Quick Actions</h2>
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4">
          {quickActions.map((action, index) => (
            <motion.button
              key={action.title}
              whileHover={{ scale: 1.02 }}
              whileTap={{ scale: 0.98 }}
              onClick={() => handleActionClick(action)}
              className={`flex items-center space-x-2 p-4 bg-[#2a2a2a] rounded-lg 
                ${adminData.permissions.includes(action.permission || '') 
                  ? 'hover:bg-[#FF6B2B] cursor-pointer' 
                  : 'opacity-50 cursor-not-allowed'}
                transition-colors duration-200 text-white`}
            >
              <span className="p-2 bg-[#FF6B2B]/10 rounded-lg">
                {action.icon}
              </span>
              <span>{action.title}</span>
            </motion.button>
          ))}
        </div>
      </div>
    </div>
  );
} 